<div class="navbar navbar-default navbar-fixed-top" role="navigation">
    <div class="container">

        <!-- Collapsed navigation -->
        <div class="navbar-header">
            {% if include_nav or include_next_prev or repo_url %}
            <!-- Expander button -->
            <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
                <span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>
            {% endif %}

            <!-- Main title -->
            <a class="navbar-brand" href="{{ homepage_url }}">{{ document.title }}</a>
        </div>
        <!--
        <div class="navbar-collapse">
            <ul class="nav navbar-nav navbar-right">
                <li class="dropdown">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown">Code samples <code>shell</code> <b class="caret"></b></a>
                    <ul class="dropdown-menu">
                        <li class="active"><a href="#">shell</a></li>
                        <li><a href="#">javascript</a></li>
                        <li><a href="#">python</a></li>
                    </ul>
                </li>
            </ul>
        </div>
        -->
    </div>
</div>
