<pre class="highlight shell"><code>{% highlight 'bash' %}# Load the schema document
$ coreapi get {{ schema_url }}{% if schema_format %} --format {{ schema_format }}{% endif %}

# Interact with the API endpoint
$ coreapi action {% if section_key %}{{ section_key }} {% endif %}{{ link_key }}{% for field in link.fields %} -p {{ field.name }}=...{% endfor %}{% endhighlight %}</code></pre>
